@@ -598,7 +598,8 @@
 (define* (udict-enums->ddict udict #:optional (ddict '()))
   (define (gen-nvl edef-list ddict)
     (let ((def-list (and=> (canize-enum-def-list edef-list udict ddict) cdr)))
-      (fold (lambda (edef dd) (acons (sx-ref* edef 1 1) (sx-ref* edef 2 1) dd))
+      (fold (lambda (edef dd)
+              (acons (sx-ref* edef 1 1) (sx-ref* edef 2 1) dd))
             ddict def-list)))
   (fold
    (lambda (pair ddict)
